@@ -1,27 +1,29 @@
 from collections import defaultdict
 from difflib import unified_diff
 from pathlib import Path
-from typing import List, Tuple, Dict, Iterator, Iterable, Optional
+from typing import List, Tuple, Dict, Iterator, Iterable, Optional, Pattern
 
 import click
 from robot.api import get_model
 from robot.errors import DataError
 
 from robotidy.transformers import load_transformers
+from robotidy.files import get_paths
 from robotidy.utils import (
     StatementLinesCollector,
     decorate_diff_with_color,
-    GlobalFormattingConfig
+    GlobalFormattingConfig,
+    ModelWriter
 )
 
-INCLUDE_EXT = ('.robot', '.resource')
-
 
 class Robotidy:
     def __init__(self,
                  transformers: List[Tuple[str, List]],
                  transformers_config: List[Tuple[str, List]],
                  src: Tuple[str, ...],
+                 exclude: Pattern,
+                 extend_exclude: Pattern,
                  overwrite: bool,
                  show_diff: bool,
                  formatting_config: GlobalFormattingConfig,
@@ -30,7 +32,7 @@ class Robotidy:
                  output: Optional[Path],
                  force_order: bool
                  ):
-        self.sources = self.get_paths(src)
+        self.sources = get_paths(src, exclude, extend_exclude)
         self.overwrite = overwrite
         self.show_diff = show_diff
         self.check = check
@@ -74,7 +76,8 @@ class Robotidy:
 
     def save_model(self, model):
         if self.overwrite:
-            model.save(output=self.output)
+            output = self.output or model.source
+            ModelWriter(output=output, newline=self.formatting_config.line_sep).write(model)
 
     def output_diff(self, path: str, old_model: StatementLinesCollector, new_model: StatementLinesCollector):
         if not self.show_diff:
@@ -82,31 +85,11 @@ class Robotidy:
         old = old_model.text.splitlines()
         new = new_model.text.splitlines()
         lines = list(unified_diff(old, new, fromfile=f'{path}\tbefore', tofile=f'{path}\tafter'))
+        if not lines:
+            return
         colorized_output = decorate_diff_with_color(lines)
         click.echo(colorized_output.encode('ascii', 'ignore').decode('ascii'), color=True)
 
-    def get_paths(self, src: Tuple[str, ...]):
-        sources = set()
-        for s in src:
-            path = Path(s).resolve()
-            if path.is_file():
-                sources.add(path)
-            elif path.is_dir():
-                sources.update(self.iterate_dir(path.iterdir()))
-            elif s == '-':
-                sources.add(path)
-
-        return sources
-
-    def iterate_dir(self, paths: Iterable[Path]) -> Iterator[Path]:
-        for path in paths:
-            if path.is_file():
-                if path.suffix not in INCLUDE_EXT:
-                    continue
-                yield path
-            elif path.is_dir():
-                yield from self.iterate_dir(path.iterdir())
-
     @staticmethod
     def convert_configure(configure: List[Tuple[str, List]]) -> Dict[str, List]:
         config_map = defaultdict(list)
